spike.Miscellaneous package — spike 0.99.8-407 documentation

# spike.Miscellaneous package

## Submodules

## spike.Miscellaneous.big module

## spike.Miscellaneous.bruker_corr module

bruker_corr.py

Created by Marc-André on 2010-06-21. Copyright (c) 2010 IGBMC. All rights reserved.

This file contains bruker specific stuff, as digital filter correction DSPFIRM is named form bruker document, however, it seems it is called dspfvs in the header bruker files (acqu) It is thus called accordingly in the Gifa User Interface.

`spike.Miscellaneous.bruker_corr.` `brukerdelay`(dspfvs, dspfirm, decim, sw)

  The brukerphase function computes the correction for the Bruker figital filter. the phase correction to apply is computed given the 3 parameters : DSPFIRM DSPFVS DECIM as found in the acqus parameter file in XwinNMR

  dspfvs is not used so far version 1.0 10 oct 2001 - M.A.D.

`spike.Miscellaneous.bruker_corr.` `brukerdelay_2`(dspfirm, dspfvs, decim, sw)

## spike.Miscellaneous.downsample module

downsample2D.py

Created by MAD on 2011-04-14.

`spike.Miscellaneous.downsample.` `downsample2D`(data, n1=2, n2=2)

  takes data (a 2D) and generate a smaller dataset downsampled by factor (n1,n2) on each axis then returned data-set is n1*n2 times smaller - simply takes the mean

  ** Not tested on non powers of 2 **

`spike.Miscellaneous.downsample.` `downsample2D_med`(data, n1=2, n2=2)

  takes data (a 2D) and generate a smaller dataset downsampled by factor (n1,n2) on each axis the returned data-set is n1*n2 times smaller - simply takes the mean

  ** Not tested on non powers of 2 **

## spike.Miscellaneous.downsampling module

## spike.Miscellaneous.poulding module

## spike.Miscellaneous.processing2 module

## spike.Miscellaneous.stat module

## Module contents

Utilities

Created by Marc-André on 2011-03-20. Copyright (c) 2011 IGBMC. All rights reserved.

`spike.Miscellaneous.` `main`()